@@ -11,7 +11,7 @@ process.
     from csoundengine import Engine
     # create an engine with default options for the platform
     engine = Engine()
-    engine.defInstr('''
+    engine.compile('''
       instr synth
         kmidinote = p4
         kamp = p5
@@ -81,44 +81,76 @@ built-in instruments to play a sample from disk/memory, offline rendering, etc.
     for i, midinote in enumerate(range(60, 72, 2)):
         # for each synth, we create a bus to plug it to an effect, in this case a filter
         bus = session.assignBus()
+
         # start time for synth and effect
         start = i * 1
+
         # Schedule a synth
-        synth = session.sched("synth", delay=start, dur=5, kmidi=midinote, ibus=bus.busnum)
+        synth = session.sched("synth", delay=start, dur=5, kmidi=midinote, ibus=bus)
+
         # Automate the transposition of the pitch so that it goes 2 semitones
-        synth.automatep('ktransp', [0, 0, dur, -2], delay=start)
+        synth.automate('ktransp', [0, 0, dur, -2], delay=start)
+
         # Schedule the filter for this synth, with a priority higher than the
         # synth, so that it is evaluated later in the chain
         filt = session.sched("filter", delay=start, dur=5, priority=synth.priority+1,
-            kcutoff=2000, kresonance=0.92, ibus=bus.busnum)
+                             kcutoff=2000, kresonance=0.92, ibus=bus)
+
         # Automate the cutoff freq. of the filter
-        filt.automatep('kcutoff', [0, 2000, dur*0.8, 500, dur, 6000], delay=start)
+        filt.automate('kcutoff', [0, 2000, dur*0.8, 500, dur, 6000], delay=start)
 """
-# sndfileio sets numpy's denormal behaviour. If it happens later numpy spits
-# multiple warnings about it
-import sndfileio
+# This disables warning about denormals
+# import numpy as np
 
-from .config import config, setLoggingLevel
-from .dependencies import checkDependencies
-ok = checkDependencies(force=False, fix=True, timeoutDays=config['dependencies_check_timeout_days'])
-if not ok:
-    raise RuntimeError("csoundengine: Depencencies not fullfilled")
+# np.finfo(np.dtype("float32"))
+# np.finfo(np.dtype("float64"))
 
+import sys
 
-from .engine import *
-from .config import config, setLoggingLevel
+import emlib.envir
+
+from .config import config, logger
+from .engine import Engine
+# from .event import Event
 from .session import Session
-from .instr import Instr
-from .offline import Renderer
-from . import synth
-from . import csoundlib
-from . import tools
-from .csoundlib import (dumpAudioDevices, dumpAudioBackends,
-                        getAudioBackend, audioBackends)
+# from .synth import SynthGroup
 
-import emlib.misc
-if emlib.misc.inside_ipython():
-    from . import magic
-    if config['ipython_load_magics_at_startup']:
-        from IPython.core.getipython import get_ipython
-        get_ipython().extension_manager.load_extension('csoundengine.magic')
\ No newline at end of file
+
+__all__ = [
+    'config',
+    'logger',
+    'Engine',
+    'Session',
+    # 'SynthGroup',
+    # 'Event',
+    'dumpAudioInfo',
+    'installDependencies',
+]
+
+
+if 'sphinx' not in sys.modules:
+    # Not building docs
+    from .dependencies import checkDependencies, installDependencies
+    _ok = checkDependencies(force=False, fix=True)
+    if not _ok:
+        raise RuntimeError("csoundengine: Depencencies not fullfilled")
+else:
+    print("Building docs")
+    from sphinx.ext.autodoc.mock import _MockObject
+    libcsound = _MockObject()
+    sys.modules['libcsound'] = libcsound
+
+
+if emlib.envir.inside_ipython() and config['ipython_load_magics_at_startup']:
+    from IPython.core.getipython import get_ipython
+    ipython = get_ipython()
+    if ipython is not None and ipython.extension_manager is not None:
+        ipython.extension_manager.load_extension('csoundengine.magic')
+
+
+def dumpAudioInfo(backend=''):
+    """
+    Dump information about the audio backend.
+    """
+    from . import csoundlib
+    return csoundlib.dumpAudioInfo(backend=backend)
