@@ -1,8 +1,10 @@
 # depends on JACK-client: https://pypi.python.org/pypi/JACK-Client
 from __future__ import annotations
-import cachetools
+
 import dataclasses
-from typing import List, Tuple, Set, Dict, Optional
+import time
+from typing import Any
+
 from . import linuxaudio
 
 try:
@@ -13,6 +15,10 @@ except OSError:
     JACK_INSTALLED = False
 
 
+_cache: dict[str, tuple[Any, float]] = {
+}
+
+
 def isJackRunning() -> bool:
     """
     Returns True if jack is running.
@@ -31,13 +37,12 @@ class JackInfo:
     blocksize: int
     numOutChannelsPhysical: int
     numInChannelsPhysical: int
-    systemInput: JackClient
-    systemOutput: JackClient
+    systemInput: str
+    systemOutput: str
     onPipewire: bool = False
 
 
-@cachetools.cached(cache=cachetools.TTLCache(1, 20))
-def getInfo() -> Optional[JackInfo]:
+def getInfo() -> JackInfo | None:
     """
     Get info about a running jack server
 
@@ -47,6 +52,10 @@ def getInfo() -> Optional[JackInfo]:
     # assumes that jack is running
     if not JACK_INSTALLED:
         return None
+    cachedinfo, lasttime = _cache.get('getInfo', (None, 0.))
+    if lasttime > 0 and time.time() - lasttime < 20:
+        return cachedinfo
+
     try:
         c = jack.Client("jacktools-getinfo", no_start_server=True)
     except jack.JackOpenError:
@@ -56,19 +65,26 @@ def getInfo() -> Optional[JackInfo]:
     systemOutput = _buildClients(inports)[0]
     systemInput = _buildClients(outports)[0] if outports else None
     onPipewire = linuxaudio.isPipewireRunning()
-    return JackInfo(running=True,
-                    samplerate=c.samplerate,
-                    blocksize=c.blocksize,
-                    numOutChannelsPhysical=len(inports),
-                    numInChannelsPhysical=len(outports),
-                    systemInput=systemOutput,
-                    systemOutput=systemInput,
-                    onPipewire=onPipewire)
+    sr = c.samplerate
+    blocksize = c.blocksize
+    out = JackInfo(running=True,
+                   samplerate=sr,
+                   blocksize=blocksize,
+                   numOutChannelsPhysical=len(inports),
+                   numInChannelsPhysical=len(outports),
+                   systemInput=systemOutput.name,
+                   systemOutput=systemInput.name if systemInput else '',
+                   onPipewire=onPipewire)
+    c.close()
+    _cache['getInfo'] = (out, time.time())
+    return out
 
 
-def bufferSizeAndNum() -> Tuple[int, int]:
+def bufferSizeAndNum() -> tuple[int, int]:
     # assumes that jack is running
     info = getInfo()
+    if info is None:
+        raise RuntimeError("Cannot get buffer size, failed to get info about jack")
     return info.blocksize, 2
 
 
@@ -78,10 +94,11 @@ class JackClient:
     kind: str
     regex: str
     isPhysical: bool = False
-    ports: List[jack.Port] = dataclasses.field(default_factory=list)
+    ports: list[jack.Port] = dataclasses.field(default_factory=list)
+    firstIndex: int = -1
 
 
-def _splitlast(s:str, sep:str) -> Tuple[str, str]:
+def _splitlast(s:str, sep:str) -> tuple[str, str]:
     if sep not in s:
         return (s, '')
     s2 = s[::-1]
@@ -89,11 +106,11 @@ def _splitlast(s:str, sep:str) -> Tuple[str, str]:
     return first[::-1], last[::-1]
 
 
-def _buildClients(ports: List[jack.Port]) -> List[JackClient]:
+def _buildClients(ports: list[jack.Port]) -> list[JackClient]:
     assert all(p.is_output for p in ports) or all(p.is_input for p in ports)
     d = {}
     regexes = {}
-    for p in ports:
+    for i, p in enumerate(ports):
         prefix = _splitlast(p.name, ":")[0]
         # special case system monitor
         if prefix == 'system':
@@ -103,33 +120,43 @@ def _buildClients(ports: List[jack.Port]) -> List[JackClient]:
         else:
             regex = prefix + ':'
         if prefix not in d:
-            d[prefix] = [p]
+            d[prefix] = []
             regexes[prefix] = regex
-        else:
-            d[prefix].append(p)
-    return [JackClient(name,
-                       regex=regexes[name],
-                       kind='output' if ports[0].is_output else 'input',
-                       isPhysical=ports[0].is_physical,
-                       ports=ports)
-            for name, ports in d.items()]
+        d[prefix].append(i)
+
+    clients = []
+    for name, portindexes in d.items():
+        portindexes.sort()
+        port0 = ports[portindexes[0]]
+        client = JackClient(name,
+                            regex=regexes[name],
+                            kind='output' if port0.is_output else 'input',
+                            isPhysical=port0.is_physical,
+                            ports=[ports[i] for i in portindexes],
+                            firstIndex=portindexes[0])
+        clients.append(client)
+    return clients
 
 
-@cachetools.cached(cache=cachetools.TTLCache(1, 20))
-def getClients() -> List[JackClient]:
+def getClients() -> list[JackClient]:
     """
     Get a list of running clients
 
     A client of kind "output" has only output ports, which means it can be
     an input to another client
     """
+    cachedclients, lasttime = _cache.get('getClients', ([], 0.))
+    if lasttime > 0 and time.time() - lasttime < 20:
+        return cachedclients
     client = jack.Client("jacktools", no_start_server=True)
     inclients = _buildClients(client.get_ports(is_audio=True, is_input=True))
     outclients = _buildClients(client.get_ports(is_audio=True, is_output=True))
-    return inclients + outclients
+    allclients = inclients + outclients
+    _cache['getClients'] = (allclients, time.time())
+    return allclients
 
 
-def getSystemClients() -> Tuple[Optional[JackClient], Optional[JackClient]]:
+def getSystemClients() -> tuple[JackClient | None, JackClient | None]:
     """
     Returns the hardware (physical) clients (input, output)
 
